package com.zhkj.screensetting.controller;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.StrUtil;
import com.zhkj.screensetting.entity.Result;
import com.zhkj.screensetting.entity.ScreenSettingVo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

@RestController
public class ScreenSettingController {

    /**
     * 日志配置
     */
    private static Logger logger = LoggerFactory.getLogger(ScreenSettingController.class);

    /**
     * 数据持久化地址
     */
    private final String FILE_PATH = System.getProperty("user.dir") + "/jsonData/";

    /**
     * 大屏配置持久化
     * @param screenSettingList 配置信息
     */
    @RequestMapping(value = "/saveJsonSetting",method = RequestMethod.POST)
    public Result saveJsonSetting(@RequestBody List<ScreenSettingVo> screenSettingList){
        try{
            for(ScreenSettingVo screenSettingVo : screenSettingList){
                File file = FileUtil.file(FILE_PATH + screenSettingVo.getDataType() +".json");
                FileUtil.writeUtf8String(screenSettingVo.getJsonDataStr(),file);
                logger.info("配置持久化成功：" + file.getPath());
            }
            return new Result(200,"数据保存成功");
        }catch (Exception e){
            logger.error("配置持久化失败：" + e);
            return new Result(1,"数据保存失败");
        }
    }

    /**
     * 获取配置信息
     * @param dataTypes 配置类型
     * @return Result
     */
    @RequestMapping("/getSettingInfo")
    public Result getSettingInfo(@RequestBody List<String> dataTypes){
        try{
            List<ScreenSettingVo> screenSettingVoList = new ArrayList<>();
            StringBuilder notExist = new StringBuilder();
            for(String dataType : dataTypes){
                if( FileUtil.exist(FILE_PATH + dataType +".json")){
                    ScreenSettingVo screenSettingVo = new ScreenSettingVo();
                    screenSettingVo.setDataType(dataType);
                    screenSettingVo.setJsonDataStr(FileUtil.readUtf8String(FILE_PATH + dataType +".json"));
                    screenSettingVoList.add(screenSettingVo);
                }else{
                    notExist.append(dataType + "数据不存在;");
                }
            }
            if(StrUtil.isEmpty(notExist)) return new Result(200,"数据获取成功！").setData(screenSettingVoList);
            return new Result(2,notExist.toString()).setData(screenSettingVoList);
        }catch (Exception e){
            logger.error("配置获取失败:" + e);
            return new Result(1,"配置信息获取失败");
        }
    }

    /**
     * 获取配置列表
     * @return Result
     */
    @RequestMapping("/getSettingList")
    public Result getSettingList(){
        try{
            List<File> fileList = FileUtil.loopFiles(FILE_PATH);
            List<ScreenSettingVo> settings = new ArrayList<>();
            for(File file : fileList){
                ScreenSettingVo setting = new ScreenSettingVo();
                setting.setDataType( FileUtil.mainName(file));
                setting.setJsonDataStr(FileUtil.readUtf8String(file));
                settings.add(setting);
            }
            return new Result(200,"配置信息列表获取成功").setData(settings);
        }catch (Exception e){
            logger.error("配置列表获取失败：" + e);
            return new Result(1,"配置列表获取失败");
        }
    }

    /**
     * 删除配置信息
     * @param dataTypes 配置类型
     * @return Result
     */
    @RequestMapping(value = "delSetting",method = RequestMethod.POST)
    public Result delSetting(@RequestBody List<String> dataTypes){
        try {
            for(String dataType : dataTypes){
                FileUtil.del(FILE_PATH + dataType +".json");
            }
            return new Result(200,"配置信息删除成功");
        }catch (Exception e){
            logger.error("配置信息删除失败：" + e);
            return new Result(1,"配置信息删除失败");
        }
    }


}
